#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
-----------------------------------------
@ProjectName: 
@Author: 
@Date: 2024/8/10-上午11:25
@Description: 
-----------------------------------------
"""

import logging
from colorama import Fore, Style
import colorama


# 初始化 colorama
colorama.init(autoreset=True)
objName = "wechatautomation"


class ColorFormatter(logging.Formatter):
    def format(self, record):
        colors = {
            logging.DEBUG: Fore.LIGHTBLACK_EX,
            logging.INFO: Fore.GREEN,
            logging.WARNING: Fore.YELLOW,
            logging.ERROR: Fore.RED,
            logging.CRITICAL: Fore.RED + Style.BRIGHT,
        }
        color = colors.get(record.levelno, Fore.WHITE)
        log_format = (
            f'{color}[%(levelname)s]{Style.RESET_ALL} '
            f'{Fore.LIGHTBLACK_EX}%(asctime)s{Style.RESET_ALL} '
            f'{Fore.LIGHTBLACK_EX}%(logger_name)s{Style.RESET_ALL} '
            f'({Fore.CYAN}%(filename)s{Style.RESET_ALL}:{Fore.CYAN}%(lineno)d{Style.RESET_ALL}): '
            f'{color}%(message)s{Style.RESET_ALL}'
        )
        if not hasattr(record, 'logger_name'):
            record.logger_name = objName

        formatter = logging.Formatter(log_format)
        return formatter.format(record)


class wxAutomationLogger:
    def __init__(self, loggerName: str = objName):
        self.wxAutomation = logging.getLogger(loggerName)
        self.wxAutomation.setLevel(logging.DEBUG)
        self.wxAutomationLoggerHandle = logging.StreamHandler()
        self.wxAutomationLoggerHandle.setLevel(logging.DEBUG)
        self.wxAutomationLoggerFormater = ColorFormatter()
        self.wxAutomationLoggerHandle.setFormatter(self.wxAutomationLoggerFormater)
        self.wxAutomation.addHandler(self.wxAutomationLoggerHandle)
        self.wxAutomation.propagate = False


wxChatLog = wxAutomationLogger().wxAutomation
# result = read_toml()
# if result['debug']['isDeBug']:
#     wxChatLog.info("设置当前Debug级别")
#     wxChatLog.setLevel(10)
# else:
#     wxChatLog.setLevel(20)





#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
-----------------------------------------
@ProjectName: 
@Author: 
@Date: 2024/8/14-下午3:42
@Description: 
-----------------------------------------
"""
from .wxelements import wxMainBase
import uiautomation as uia
from .wxutils import *


class openWechat(wxMainBase):
    VERSION: str = "__version__"
    lastmsgid: str = None
    listen: dict = dict()
    SessionItemList: list = []
    UiaAPI: uia.WindowControl = uia.WindowControl(ClassName='WeChatMainWndForPC', searchDepth=1) \
 \
        # 功能1：语言版本可切换功能待开发

    # 实例化微信UI
    def __init__(self, isDebug: bool = False, setGlobaltime: int | str = None) -> None:
        openWechat.__switchisDebug(isDebug)
        # 弹出微信窗体
        self._show(HWND=self.UiaAPI)

    @staticmethod
    def __switchisDebug(isDebug: bool) -> None:
        if isDebug:
            wxChatLog.setLevel(10)
            wxChatLog.debug("开启debug")
        else:
            wxChatLog.setLevel(20)
            wxChatLog.info("关闭debug")


if __name__ == '__main__':
    wx = openWechat()



# !/usr/bin/env python
# -*- coding: utf-8 -*-
"""
-----------------------------------------
@ProjectName:
@Author:
@Date: 2024/8/10-下午5:11
@Description: 
-----------------------------------------
"""
from .wxlogging import wxChatLog
from win32gui import FindWindow
from win32process import GetWindowThreadProcessId
from psutil import Process
from typing import Dict, Union, Type
import uiautomation as uia

# 支持版本
VERSION = "3.9.11.17"

uia.SetGlobalSearchTimeout(0)


def ceshi1():
    wxChatLog.debug(1111111111111111)
    wxChatLog.error("123")


def wxFindWindow(contronlClass: str = None, controlName: str = None, ):
    """
    通过窗口类名或者窗口标题查找窗口句柄
    """
    try:
        wxChatLog.debug("查找窗口句柄", extra={'logger_name': 'FindWindow()'})
        return FindWindow(contronlClass, controlName)
    except Exception as e:
        wxChatLog.critical(e, extra={'logger_name': '111'})


# 通过HWND获取窗口路径信息
def wxGetPathByHwnd(hwnd):
    """
    通过窗口句柄获取窗口路径信息
    """
    try:
        threading_id, process_id = GetWindowThreadProcessId(hwnd)
        process = Process(process_id)
        return process.exe()
    except Exception as e:
        wxChatLog.critical(e, extra={'logger_name': 'GetPathByHwnd()'})
        return None



# -*- coding: utf-8 -*-
# !/usr/bin/env python
import codecs
import os

from setuptools import find_packages, setup

# these things are needed for the README.md show on pypi
here = os.path.abspath(os.path.dirname(__file__))

with codecs.open(os.path.join(here, "README.md"), encoding="utf-8") as fh:
    long_description = "\n" + fh.read()




VERSION = '0.1.5'
DESCRIPTION = '微信自动化程序'
LONG_DESCRIPTION = 'None'

# 使用setuptools的setup函数来配置和安装Python包
setup(
    # 包的名称
    name="wechatautomation",
    # 包的版本号，使用预定义的VERSION变量
    version=VERSION,
    # 作者姓名
    author="Anthony Lee",
    # 作者电子邮件，此处为空字符串
    author_email="1020343877@qq.com",
    # 包的简短描述
    description=DESCRIPTION,
    # 长描述的内容类型，此处指定为markdown格式
    long_description_content_type="text/markdown",
    # 长描述的文本，通常包含包的详细信息和使用说明
    long_description=long_description,
    # 自动发现和包含所有Python包
    packages=find_packages(),
    include_package_data=True,
    # 定义包的依赖关系，根据不同的操作系统选择不同的getch库
    install_requires=list(
        map(lambda x: x.replace('==', '>=').rstrip('\n'), open("requirements.txt", encoding="utf-8").readlines())),
    # 关键词列表，用于在包仓库中帮助用户搜索
    keywords=['python', 'uiautomation', 'toml', 'wechat', 'wxauto'],
    # 包的分类信息，用于在包仓库中对包进行分类
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: Unix"
    ]
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""
-----------------------------------------
@ProjectName: PyServer
@Author: Anthony Lee
@Date: 2024/8/10-下午9:46
@Description: 
-----------------------------------------
"""

from wxlogging import wxChatLog
from wxutils import *
import uiautomation as uia
import datetime
import time
import os
import re
import win32gui


class wxMainBase:
    def _show(self, HWND):
        try:
            self.HWND = wxFindWindow(contronlClass="WeChatMainWndForPC")
            wxChatLog.debug(f"当前用户界面窗口句柄：{self.HWND}")
            win32gui.ShowWindow(self.HWND, 1)
            win32gui.SetWindowPos(self.HWND, -1, 0, 0, 0, 0, 3)
            win32gui.SetWindowPos(self.HWND, -2, 0, 0, 0, 0, 3)
            HWND.SwitchToThisWindow()
        except Exception as e:
            wxChatLog.error(e)

    @property
    def _app_path(self):
        wxChatLog.debug(f"当前用户界面窗口句柄：私有属性待开发")


# 登录窗体
class wechatLoginHandle:
    _uiaClassName = 'WeChatLoginWndForPC'
    wxuiaMainApi = uia.PaneControl(ClassName=_uiaClassName, searchDepth=1)

    def __repr__(self) -> str:
        return f"<wxAutomation.wechatHandle object at {hex(id(self))}>"

    # 前置微信窗口
    def _show(self):
        try:
            # 获取窗口句柄
            self.wxHWND = wxFindWindow(contronlClass="WeChatMainWndForPC")
            wxChatLog.debug(f"当前窗口句柄：{self.wxHWND}")
            # 显示窗口，参数1表示可见
            win32gui.ShowWindow(self.wxHWND, 1)
            win32gui.SetWindowPos(self.wxHWND, -1, 0, 0, 0, 0, 3)
            win32gui.SetWindowPos(self.wxHWND, -2, 0, 0, 0, 0, 3)
            self.wxuiaMainApi.SwitchToThisWindow()
        except Exception as e:
            wxChatLog.error(e)

    # 返回窗口句柄的路径信息
    @property
    def _app_path(self):
        HWND = wxFindWindow(contronlClass="WeChatMainWndForPC")
        wxChatLog.debug(f"当前登录界面窗口句柄：{wxGetPathByHwnd(HWND)}")
        return wxGetPathByHwnd(HWND)

    # 点击进入微信
    def clickLogin(self):
        wxLoginButton = self.wxuiaMainApi.ButtonControl(Name='进入微信')
        # if wxLoginButton.Exists():
        #     wxLoginButton.Click(simulateMove=isMouseTracks)


if __name__ == '__main__':
    wechat_instance = wechatLoginHandle()
    wechat_instance._show()
    wechat_instance.clickLogin()
